.. _examples-handling:

Handling
========

Examples about **warping**, **reprojecting**, **resampling**, **cropping**, as well as **rasterizing** and **polygonizing** of georeferenced data.

All of these methods support simply passing a reference to match (see :ref:`core-match-ref`).
